local MAJOR_VERSION = "LibDogTag-2.0"
local MINOR_VERSION = tonumber(("$Revision: 60032 $"):match("%d+")) or 0

if MINOR_VERSION > _G.DogTag_MINOR_VERSION then
	_G.DogTag_MINOR_VERSION = MINOR_VERSION
end

DogTag_funcs[#DogTag_funcs+1] = function()

local L = DogTag.L

DogTag:AddModifier("Negate", {
	alias = "Mult(-1)",
	doc = L["Turn positive number_value into negative or vice-versa"],
	example = '[50:Negate] => "-50"; [0:Negate] => "0"; [Text(-50):Negate] => "50"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Round", {
	function(data)
		if type(data.arg) ~= "string" then
			local arg = math.floor((data.arg or 0) + 0.5)
			if arg == 0 then
				return [[value = math_floor(value + 0.5)]]
			else
				return [[value = math_floor(value * (10^]] .. arg .. [[) + 0.5) / (10^]] .. arg .. [[)]]
			end
		else -- dynamic
			return [[value = math_floor(value * (10^${arg}) + 0.5) / (10^${arg})]]
		end
	end,
	arg = "nil;number",
	value = "number",
	ret = "number",
	globals = "math.floor",
	doc = L["Round number_value to the one's place or the place specified by number"],
	example = '[1234.5:Round] => "1235"; [1234:round(-2)] => "1200"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Add", {
	[[value = value + ${arg}]],
	arg = "number",
	value = "number",
	ret = "number",
	doc = L["Add number to number_value"],
	example = '[100:Add(50)] => "150"; [100+50] => "150"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Sub", {
	[[value = value - ${arg}]],
	arg = "number",
	value = "number",
	ret = "number",
	doc = L["Subtract number from number_value"],
	example = '[100:Sub(25)] => "75"; [100-25] => "75"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Mult", {
	function(data)
		if data.arg == 1 then
			return [[]]
		elseif data.arg == -1 then
			return [[if value ~= 0 then
				value = -value
			end]]
		end
		return [[if value ~= 0 then
			value = value * ${arg}
		end]]
	end,
	arg = "number",
	value = "number",
	ret = "number",
	doc = L["Multiply number with number_value"],
	example = '[10:Mult(25)] => "250"; [10*25] => "250"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Div", {
	function(data)
		if data.arg == 1 then
			return [[]]
		elseif data.arg == -1 then
			return [[if value ~= 0 then
				value = -value
			end]]
		end
		return [[if value ~= 0 then
			value = value / ${arg}
		end]]
	end,
	arg = "number",
	value = "number",
	ret = "number",
	doc = L["Divide number from number_value"],
	example = '[75:Div(50)] => "1.5"; [75/50] => "1.5"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Pow", {
	[[value = value ^ ${arg}]],
	arg = "number",
	value = "number",
	ret = "number",
	doc = L["Raise number_value to the power of number"],
	example = '[2:Pow(4)] => "16"; [2^4] => "16"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Mod", {
	[[value = value % ${arg}]],
	arg = "number",
	value = "number",
	ret = "number",
	doc = L["Take the modulus of number_value by number"],
	example = '[15:Mod(4)] => "3"; [15%4] => "3"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Floor", {
	[[value = math_floor(value)]],
	value = "number",
	ret = "number",
	globals = "math.floor",
	doc = L["Take the floor of number_value"],
	example = '[9.876:Floor] => "9"',
	category = L["Mathematics"]
})

DogTag:AddModifier("Ceil", {
	[[value = math_ceil(value)]],
	value = "number",
	ret = "number",
	globals = "math.ceil",
	doc = L["Take the ceiling of number_value"],
	example = '[1.234:Ceil] => "2"',
	category = L["Mathematics"]
})

end
